@@ -121,7 +121,7 @@ bool read_edges_and_nodes_withoptimIO(char* filename_info,
 
 //Type used to represent a path.
 //It keeps track of the length (distance) of the path, its number of branching nodes and its nodes
-typedef struct Path {
+struct Path {
     int distance;
     int branchingNodes;
     vector<int> nodes;
