@@ -71,10 +71,10 @@
 // ===========================================================================
 //                             Include Project Files
 // ===========================================================================
-#include <NGraph.h>
-#include <debug.h>
-#include <CycleCompression.h>
-#include <Utils.h>
+#include "NGraph.h"
+#include "debug.h"
+#include "CycleCompression.h"
+#include "Utils.h"
 
 
 
@@ -110,16 +110,6 @@ NGraph::NGraph( int kValue, int outputtedSnps )
 
 }
 
-NGraph::NGraph( const NGraph &model )
-{
-  _kValue     = model._kValue;
-  _nodes      = model._nodes;
-  _nbOutput  = model._nbOutput;
-  _nodeToStr  = model._nodeToStr;
-  _strToNode  = model._strToNode;
-}
-
-
 /*!
   TODO : check : Create a NGraph for the BCC passed in edges ? all_edges ?
 */
@@ -147,14 +137,6 @@ NGraph::NGraph( CGraph& cgraph, vector<char *>& seqs,
 }
 
 
-// ===========================================================================
-//                                  Destructors
-// ===========================================================================
-NGraph::~NGraph(void)
-{
-}
-
-
 // ===========================================================================
 //                                 Public Methods
 // ===========================================================================
